@@ -109,7 +109,7 @@ class Games(QDialog):
         super(Games, self).__init__(parent)
         self.selectedGame = None
         self.onlyPending = True
-        decorateWindow(self, i18nc("@title:window" "Games"))
+        decorateWindow(self, i18nc("@title:window", "Games"))
         self.setObjectName('Games')
         self.resize(700, 400)
         self.model = GamesModel()
