@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -36,13 +36,16 @@ from qt import QDialog, QDialogButtonBox, QVBoxLayout, \
     QLabel, QComboBox, QLineEdit, QFormLayout, \
     QSizePolicy, QWidget
 
-from kde import KUser, KDialog, KDialogButtonBox, appdataDir, socketName
-from dialogs import DeferredDialog, QuestionYesNo, MustChooseKDialog
+from kde import KUser, KDialog, KDialogButtonBox
+from mi18n import i18n, i18nc, english
+from dialogs import DeferredDialog, QuestionYesNo
 
-from log import logWarning, logException, logInfo, logDebug, m18n, m18nc, SERVERMARK
+from log import logWarning, logException, logInfo, logDebug, SERVERMARK
 from util import removeIfExists, which
-from common import Internal, Options, SingleshotOptions, Debug, isAlive, english, unicode
-from common import isPython3, nativeString, unicodeString, interpreterName
+from common import Internal, Options, SingleshotOptions, Debug, isAlive
+from common import interpreterName
+from common import StrMixin
+from common import appdataDir, socketName
 from game import Players
 from query import Query
 from statesaver import StateSaver
@@ -57,11 +60,10 @@ class LoginAborted(Exception):
     pass
 
 
-class Url(unicode):
+class Url(str, StrMixin):
 
     """holds connection related attributes: host, port, socketname"""
     # pylint: disable=too-many-public-methods
-    # TODO: base content: host:port
     def __new__(cls, url):
         assert url
         host = None
@@ -72,7 +74,7 @@ class Url(unicode):
             host = '127.0.0.1'
         if len(urlParts) > 1:
             port = int(urlParts[1])
-        obj = unicode.__new__(cls, url)
+        obj = str.__new__(cls, url)
         obj.host = host
         obj.port = port
         if Options.port:
@@ -84,22 +86,14 @@ class Url(unicode):
         if Debug.connections:
             logDebug(repr(obj))
 
-        if Internal.reactor is None:
-            import qt4reactor
-            qt4reactor.install()
-            from twisted.internet import reactor
-            reactor.runReturn(installSignalHandlers=False)
-            Internal.reactor = reactor
-            if Debug.quit:
-                logDebug(u'Installed qt4reactor')
         return obj
 
-    def __repr__(self):
+    def __str__(self):
         """show all info"""
         if self.useSocket:
-            return 'Url({} socket={})'.format(self, socketName())
+            return socketName()
         else:
-            return 'Url({} host={} port={})'.format(self, nativeString(self.host), self.port)
+            return '{}:{}'.format(self.host, self.port)
 
     @property
     def useSocket(self):
@@ -143,22 +137,20 @@ class Url(unicode):
                 if waiting == 0:
                     self.__startLocalServer()
                 elif waiting > 30:
-                    logDebug(u'Game %s: Server %s not available after 30 seconds, aborting' % (
+                    logDebug('Game %s: Server %s not available after 30 seconds, aborting' % (
                         SingleshotOptions.game, self))
                     raise CancelledError
                 return deferLater(Internal.reactor, 1, self.startServer, result, waiting + 1)
-        elif which('XXqdbus'):
-            # TODO: use twisted process because we must have a timeout. If the qdbus service
-            # does not answer, qdbus waits for 25 seconds.
-            # the state of QtDBus is unclear to me.
-            # riverbank.computing says module dbus is deprecated
-            # for Python 3. And Ubuntu has no package with
-            # QtDBus. So we use good old subprocess.
-            stdoutdata, stderrdata = subprocess.Popen(
-                ['qdbus',
-                 'org.kde.kded',
-                 '/modules/networkstatus',
-                 'org.kde.Solid.Networking.status'], stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
+        elif which('qdbus'):
+            try:
+                stdoutdata, stderrdata = subprocess.Popen(
+                    ['qdbus',
+                     'org.kde.kded',
+                     '/modules/networkstatus',
+                     'org.kde.Solid.Networking.status'],
+                    stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate(timeout=1)
+            except subprocess.TimeoutExpired:
+                raise twisted.internet.error.ConnectError()
             stdoutdata = stdoutdata.strip()
             stderrdata = stderrdata.strip()
             if stderrdata == '' and stdoutdata != '4':
@@ -187,7 +179,7 @@ class Url(unicode):
         else:
             result = ['kajonggserver']
         if Debug.connections:
-            logDebug(m18n('trying to start local server %1', result))
+            logDebug(i18n('trying to start local server %1', result))
         return result
 
     def __startLocalServer(self):
@@ -198,14 +190,14 @@ class Url(unicode):
                 args.append('--socket=%s' % socketName())
                 if removeIfExists(socketName()):
                     logInfo(
-                        m18n('removed stale socket <filename>%1</filename>', socketName()))
+                        i18n('removed stale socket <filename>%1</filename>', socketName()))
             if not self.useSocket:
                 args.append('--port=%d' % self.port)
             if self.isLocalGame:
                 args.append(
-                    u'--db={}'.format(
+                    '--db={}'.format(
                         os.path.normpath(
-                            appdataDir() + u'local{}.db'.format('3' if isPython3 else ''))))
+                            os.path.join(appdataDir(), 'local3.db'))))
             if Debug.argString:
                 args.append('--debug=%s' % Debug.argString)
             if os.name == 'nt':
@@ -218,10 +210,11 @@ class Url(unicode):
                 startupinfo=startupinfo)  # , shell=os.name == 'nt')
             if Debug.connections:
                 logDebug(
-                    m18n(
+                    i18n(
                         'started the local kajongg server: pid=<numid>%1</numid> %2',
                         process.pid, ' '.join(args)))
         except OSError as exc:
+            exc.filename = ' '.join(args)
             logException(exc)
 
     def __serverListening(self):
@@ -259,13 +252,13 @@ class LoginDlg(QDialog):
     def __init__(self):
         """self.servers is a list of tuples containing server and last playername"""
         QDialog.__init__(self, None)
-        decorateWindow(self, m18n('Login'))
+        decorateWindow(self, i18nc('kajongg', 'Login'))
         self.setupUi()
 
-        localName = m18n(Query.localServerName)
+        localName = i18nc('kajongg name for local game server', Query.localServerName)
         self.servers = Query(
             'select url,lastname from server order by lasttime desc').records
-        servers = [m18n(x[0]) for x in self.servers]
+        servers = list(x[0] for x in self.servers if x[0] != Query.localServerName)
         # the first server combobox item should be default: either the last used server
         # or localName for autoPlay
         if localName not in servers:
@@ -294,30 +287,30 @@ class LoginDlg(QDialog):
 
     def setupUi(self):
         """create all Ui elements but do not fill them"""
-        buttonBox = KDialogButtonBox(self)
-        buttonBox.setStandardButtons(
+        self.buttonBox = KDialogButtonBox(self)
+        self.buttonBox.setStandardButtons(
             QDialogButtonBox.Cancel | QDialogButtonBox.Ok)
         # Ubuntu 11.10 unity is a bit strange - without this, it sets focus on
         # the cancel button (which it shows on the left). I found no obvious
         # way to use setDefault and setAutoDefault for fixing this.
-        buttonBox.button(QDialogButtonBox.Ok).setFocus(True)
-        buttonBox.accepted.connect(self.accept)
-        buttonBox.rejected.connect(self.reject)
+        self.buttonBox.button(QDialogButtonBox.Ok).setFocus(True)
+        self.buttonBox.accepted.connect(self.accept)
+        self.buttonBox.rejected.connect(self.reject)
         vbox = QVBoxLayout(self)
         self.grid = QFormLayout()
         self.cbServer = QComboBox()
         self.cbServer.setEditable(True)
-        self.grid.addRow(m18n('Game server:'), self.cbServer)
+        self.grid.addRow(i18n('Game server:'), self.cbServer)
         self.cbUser = QComboBox()
         self.cbUser.setEditable(True)
-        self.grid.addRow(m18n('Username:'), self.cbUser)
+        self.grid.addRow(i18n('Username:'), self.cbUser)
         self.edPassword = QLineEdit()
         self.edPassword.setEchoMode(QLineEdit.PasswordEchoOnEdit)
-        self.grid.addRow(m18n('Password:'), self.edPassword)
+        self.grid.addRow(i18n('Password:'), self.edPassword)
         self.cbRuleset = ListComboBox()
-        self.grid.addRow(m18nc('kajongg', 'Ruleset:'), self.cbRuleset)
+        self.grid.addRow(i18nc('kajongg', 'Ruleset:'), self.cbRuleset)
         vbox.addLayout(self.grid)
-        vbox.addWidget(buttonBox)
+        vbox.addWidget(self.buttonBox)
         pol = QSizePolicy()
         pol.setHorizontalPolicy(QSizePolicy.Expanding)
         self.cbUser.setSizePolicy(pol)
@@ -344,7 +337,7 @@ class LoginDlg(QDialog):
                 userIdx = self.cbUser.findText(userNames[0])
                 if userIdx >= 0:
                     self.cbUser.setCurrentIndex(userIdx)
-        showPW = not Url(self.url).isLocalHost
+        showPW = bool(self.url) and not Url(self.url).isLocalHost
         self.grid.labelForField(self.edPassword).setVisible(showPW)
         self.edPassword.setVisible(showPW)
         self.grid.labelForField(
@@ -357,6 +350,7 @@ class LoginDlg(QDialog):
                 self.cbRuleset.items = [Options.ruleset]
             else:
                 self.cbRuleset.items = Ruleset.selectableRulesets(self.url)
+        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(bool(self.url))
 
     def __defineRuleset(self):
         """find out what ruleset to use"""
@@ -369,8 +363,7 @@ class LoginDlg(QDialog):
 
     def userChanged(self, text):
         """the username has been changed, lookup password"""
-        text = unicode(text)
-        if text == u'':
+        if text == '':
             self.edPassword.clear()
             return
         passw = None
@@ -385,17 +378,17 @@ class LoginDlg(QDialog):
     @property
     def url(self):
         """abstracts the url of the dialog"""
-        return english(unicode(self.cbServer.currentText()))
+        return english(self.cbServer.currentText())
 
     @property
     def username(self):
         """abstracts the username of the dialog"""
-        return unicode(self.cbUser.currentText())
+        return self.cbUser.currentText()
 
     @property
     def password(self):
         """abstracts the password of the dialog"""
-        return unicode(self.edPassword.text())
+        return self.edPassword.text()
 
     @password.setter
     def password(self, password):
@@ -403,28 +396,28 @@ class LoginDlg(QDialog):
         self.edPassword.setText(password)
 
 
-class AddUserDialog(MustChooseKDialog):
+class AddUserDialog(KDialog):
 
     """add a user account on a server: This dialog asks for the needed attributes"""
     # pylint: disable=too-many-instance-attributes
 
     def __init__(self, url, username, password):
-        MustChooseKDialog.__init__(self)
-        decorateWindow(self, m18n('Create User Account'))
+        KDialog.__init__(self)
+        decorateWindow(self, i18nc("@title:window", "Create User Account"))
         self.setButtons(KDialog.ButtonCode(KDialog.Ok | KDialog.Cancel))
         vbox = QVBoxLayout()
         grid = QFormLayout()
         self.lbServer = QLabel()
         self.lbServer.setText(url)
-        grid.addRow(m18n('Game server:'), self.lbServer)
+        grid.addRow(i18n('Game server:'), self.lbServer)
         self.lbUser = QLabel()
-        grid.addRow(m18n('Username:'), self.lbUser)
+        grid.addRow(i18n('Username:'), self.lbUser)
         self.edPassword = QLineEdit()
         self.edPassword.setEchoMode(QLineEdit.PasswordEchoOnEdit)
-        grid.addRow(m18n('Password:'), self.edPassword)
+        grid.addRow(i18n('Password:'), self.edPassword)
         self.edPassword2 = QLineEdit()
         self.edPassword2.setEchoMode(QLineEdit.PasswordEchoOnEdit)
-        grid.addRow(m18n('Repeat password:'), self.edPassword2)
+        grid.addRow(i18n('Repeat password:'), self.edPassword2)
         vbox.addLayout(grid)
         widget = QWidget(self)
         widget.setLayout(vbox)
@@ -456,7 +449,7 @@ class AddUserDialog(MustChooseKDialog):
     @property
     def username(self):
         """abstracts the username of the dialog"""
-        return unicode(self.lbUser.text())
+        return self.lbUser.text()
 
     @username.setter
     def username(self, username):
@@ -466,7 +459,7 @@ class AddUserDialog(MustChooseKDialog):
     @property
     def password(self):
         """abstracts the password of the dialog"""
-        return unicode(self.edPassword.text())
+        return self.edPassword.text()
 
     @password.setter
     def password(self, password):
@@ -474,7 +467,7 @@ class AddUserDialog(MustChooseKDialog):
         self.edPassword.setText(password)
 
 
-class Connection(object):
+class Connection:
 
     """creates a connection to server"""
 
@@ -527,7 +520,7 @@ class Connection(object):
         if self.url.isLocalHost:
             # we have localhost if we play a Local Game: client and server are identical,
             # we have no security concerns about creating a new account
-            Players.createIfUnknown(unicode(self.dlg.cbUser.currentText()))
+            Players.createIfUnknown(self.dlg.cbUser.currentText())
 
     def __startServer(self, result):
         """if needed"""
@@ -572,7 +565,7 @@ class Connection(object):
         for client in self.client.humanClients:
             if client.connection and client.connection.url == self.url:
                 logWarning(
-                    m18n('You are already connected to server %1', self.url))
+                    i18n('You are already connected to server %1', self.url))
                 client.tableList.activateWindow()
                 raise CancelledError
 
@@ -595,9 +588,6 @@ class Connection(object):
                                  self.dlg.password).exec_():
                 raise CancelledError
             Players.createIfUnknown(self.username)
-        # TODO: are dlg.username/password always unicode?
-        assert isinstance(self.dlg.username, unicode), self.dlg.username
-        assert isinstance(self.dlg.password, unicode), self.dlg.password
         adduserCmd = SERVERMARK.join(
             ['adduser', self.dlg.username, self.dlg.password])
         return self.loginCommand(adduserCmd)
@@ -615,7 +605,7 @@ class Connection(object):
             if self.url.isLocalHost:
                 return answered(True)
             else:
-                msg = m18nc('USER is not known on SERVER',
+                msg = i18nc('USER is not known on SERVER',
                             '%1 is not known on %2, do you want to open an account?', self.dlg.username, self.url.host)
                 return QuestionYesNo(msg).addCallback(answered)
         else:
@@ -629,29 +619,28 @@ class Connection(object):
         if failure.check(CancelledError):
             pass
         elif failure.check(twisted.internet.error.TimeoutError):
-            msg = m18n('Server %1 did not answer', self.url)
+            msg = i18n('Server %1 did not answer', self.url)
         elif failure.check(twisted.internet.error.ConnectionRefusedError):
-            msg = m18n('Server %1 refused connection', self.url)
+            msg = i18n('Server %1 refused connection', self.url)
         elif failure.check(twisted.internet.error.ConnectionLost):
-            msg = m18n('Server %1 does not run a kajongg server', self.url)
+            msg = i18n('Server %1 does not run a kajongg server', self.url)
         elif failure.check(twisted.internet.error.DNSLookupError):
-            msg = m18n('Address for server %1 cannot be found', self.url)
+            msg = i18n('Address for server %1 cannot be found', self.url)
         elif failure.check(twisted.internet.error.ConnectError):
-            msg = m18n(
+            msg = i18n(
                 'Login to server %1 failed: You have no network connection',
                 self.url)
         else:
-            tracebackString = unicodeString(failure.getTraceback())
-            msg = u'Login to server {} failed: {}/{} Callstack:{}'.format(
+            msg = 'Login to server {} failed: {}/{} Callstack:{}'.format(
                 self.url, failure.value.__class__.__name__, failure.getErrorMessage(
                 ),
-                tracebackString)
+                failure.getTraceback())
         # Maybe the server is running but something is wrong with it
-        if self.url.useSocket:
+        if self.url and self.url.useSocket:
             if removeIfExists(socketName()):
                 logInfo(
-                    m18n('removed stale socket <filename>%1</filename>', socketName()))
-            msg += u'\n\n\n' + m18n('Please try again')
+                    i18n('removed stale socket <filename>%1</filename>', socketName()))
+            msg += '\n\n\n' + i18n('Please try again')
         self.dlg = None
         if msg:
             logWarning(msg)
