@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -20,12 +20,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 # pylint: disable=ungrouped-imports
 
-from qt import Qt, usingQt5, QPointF, toQVariant, variantValue, \
-    QSize, QModelIndex, QEvent, QTimer
-from kde import usingKDE
-
-if usingKDE:
-    from qt import SLOT
+from qt import Qt, QPointF, QSize, QModelIndex, QEvent, QTimer
 
 from qt import QColor, QPushButton, QPixmapCache
 from qt import QWidget, QLabel, QTabWidget
@@ -42,9 +37,9 @@ from kde import KDialogButtonBox, KApplication
 from modeltest import ModelTest
 
 from rulesetselector import RuleTreeView
-from board import WindLabel, WINDPIXMAPS
-from log import m18n, m18nc
-from common import Internal, Debug, unicode
+from board import WindLabel
+from mi18n import i18n, i18nc
+from common import Internal, Debug
 from statesaver import StateSaver
 from query import Query
 from guiutil import ListComboBox, Painter, decorateWindow, BlockSignals
@@ -90,7 +85,7 @@ class ScoreGroupItem(ScoreTreeItem):
 
     def content(self, column):
         """return content stored in this item"""
-        return m18n(self.rawContent)
+        return i18n(self.rawContent)
 
 
 class ScorePlayerItem(ScoreTreeItem):
@@ -103,7 +98,7 @@ class ScorePlayerItem(ScoreTreeItem):
     def content(self, column):
         """return the content stored in this node"""
         if column == 0:
-            return m18n(self.rawContent[0])
+            return i18n(self.rawContent[0])
         else:
             try:
                 return self.hands()[column - 1]
@@ -203,7 +198,7 @@ class ScoreModel(TreeModel):
         """score table"""
         # pylint: disable=too-many-return-statements
         if not index.isValid():
-            return toQVariant()
+            return
         column = index.column()
         item = index.internalPointer()
         if role is None:
@@ -220,42 +215,41 @@ class ScoreModel(TreeModel):
                         content = str(content.payments)
                     else:
                         content = str(content.balance)
-                return toQVariant(content)
+                return content
             else:
                 if column > 0:
-                    return toQVariant('')
+                    return ''
                 else:
-                    return toQVariant(item.content(0))
+                    return item.content(0)
         if role == Qt.TextAlignmentRole:
             if index.column() == 0:
-                return toQVariant(int(Qt.AlignLeft | Qt.AlignVCenter))
+                return int(Qt.AlignLeft | Qt.AlignVCenter)
             else:
-                return toQVariant(int(Qt.AlignRight | Qt.AlignVCenter))
+                return int(Qt.AlignRight | Qt.AlignVCenter)
         if role == Qt.FontRole:
             return QFont('Monospaced')
         if role == Qt.ForegroundRole:
             if isinstance(item, ScorePlayerItem) and item.parent.row() == 3:
                 content = item.content(column)
                 if not isinstance(content, HandResult):
-                    return toQVariant(QBrush(ScoreItemDelegate.colors[index.row()]))
+                    return QBrush(ScoreItemDelegate.colors[index.row()])
         if column > 0 and isinstance(item, ScorePlayerItem):
             content = item.content(column)
             # pylint: disable=maybe-no-member
             # pylint thinks content is a str
             if role == Qt.BackgroundRole:
                 if content and content.won:
-                    return toQVariant(QColor(165, 255, 165))
+                    return QColor(165, 255, 165)
             if role == Qt.ToolTipRole:
                 englishHints = content.manualrules.split('||')
-                tooltip = '<br />'.join(m18n(x) for x in englishHints)
-                return toQVariant(tooltip)
-        return toQVariant()
+                tooltip = '<br />'.join(i18n(x) for x in englishHints)
+                return tooltip
 
     def headerData(self, section, orientation, role):
         """tell the view about the wanted headers"""
         if role == Qt.DisplayRole and orientation == Qt.Horizontal:
             if section == 0:
-                return m18n('Round/Hand')
+                return i18n('Round/Hand')
             child1 = self.rootItem.children[0]
             if child1 and child1.children:
                 child1 = child1.children[0]
@@ -265,10 +259,9 @@ class ScoreModel(TreeModel):
                     return handResult.handId()
         elif role == Qt.TextAlignmentRole:
             if section == 0:
-                return toQVariant(int(Qt.AlignLeft | Qt.AlignVCenter))
+                return int(Qt.AlignLeft | Qt.AlignVCenter)
             else:
-                return toQVariant(int(Qt.AlignRight | Qt.AlignVCenter))
-        return toQVariant()
+                return int(Qt.AlignRight | Qt.AlignVCenter)
 
     def loadData(self):
         """loads all data from the data base into a 2D matrix formatted like the wanted tree"""
@@ -278,16 +271,16 @@ class ScoreModel(TreeModel):
             'select player,rotated,notrotated,penalty,won,prevailing,wind,points,payments,balance,manualrules'
             ' from score where game=? order by player,hand', (game.gameid,)).records
         humans = sorted(
-            (x for x in game.players if not x.name.startswith(u'Robot')))
+            (x for x in game.players if not x.name.startswith('Robot')))
         robots = sorted(
-            (x for x in game.players if x.name.startswith(u'Robot')))
+            (x for x in game.players if x.name.startswith('Robot')))
         data = list(tuple([player.localName, [HandResult(*x[1:]) for x in records
                                               if x[0] == player.nameid]]) for player in humans + robots)
         self.__findMinMaxChartPoints(data)
         parent = QModelIndex()
         groupIndex = self.index(self.rootItem.childCount(), 0, parent)
-        groupNames = [m18nc('kajongg', 'Score'), m18nc('kajongg', 'Payments'),
-                      m18nc('kajongg', 'Balance'), m18nc('kajongg', 'Chart')]
+        groupNames = [i18nc('kajongg', 'Score'), i18nc('kajongg', 'Payments'),
+                      i18nc('kajongg', 'Balance'), i18nc('kajongg', 'Chart')]
         for idx, groupName in enumerate(groupNames):
             self.insertRows(idx, list([ScoreGroupItem(groupName)]), groupIndex)
             listIndex = self.index(idx, 0, groupIndex)
@@ -309,7 +302,7 @@ class ScoreModel(TreeModel):
         self.maxY += 2
 
 
-class HandResult(object):
+class HandResult:
 
     """holds the results of a hand for the scoring table"""
     # pylint: disable=too-many-arguments
@@ -433,7 +426,7 @@ class ScoreTable(QWidget):
         self.scene = scene
         self.scoreModel = None
         self.scoreModelTest = None
-        decorateWindow(self, m18nc('kajongg', 'Scores'))
+        decorateWindow(self, i18nc('kajongg', 'Scores'))
         self.setAttribute(Qt.WA_AlwaysShowToolTips)
         self.setMouseTracking(True)
         self.__tableFields = ['prevailing', 'won', 'wind',
@@ -460,12 +453,8 @@ class ScoreTable(QWidget):
         self.viewRight.setHorizontalScrollBar(HorizontalScrollBar(self))
         self.viewRight.setHorizontalScrollMode(QAbstractItemView.ScrollPerItem)
         self.viewRight.setFocusPolicy(Qt.NoFocus)
-        if usingQt5:
-            self.viewRight.header().setSectionsClickable(False)
-            self.viewRight.header().setSectionsMovable(False)
-        else:
-            self.viewRight.header().setClickable(False)
-            self.viewRight.header().setMovable(False)
+        self.viewRight.header().setSectionsClickable(False)
+        self.viewRight.header().setSectionsMovable(False)
         self.viewRight.setSelectionMode(QAbstractItemView.NoSelection)
         windowLayout = QVBoxLayout(self)
         self.splitter = QSplitter(Qt.Vertical)
@@ -479,7 +468,7 @@ class ScoreTable(QWidget):
         self.scoreLayout.addLayout(leftLayout)
         self.scoreLayout.addWidget(self.viewRight)
         self.splitter.addWidget(scoreWidget)
-        self.ruleTree = RuleTreeView(m18nc('kajongg', 'Used Rules'))
+        self.ruleTree = RuleTreeView(i18nc('kajongg', 'Used Rules'))
         self.splitter.addWidget(self.ruleTree)
         # this shows just one line for the ruleTree - so we just see the
         # name of the ruleset:
@@ -491,7 +480,7 @@ class ScoreTable(QWidget):
         result.setWidth(result.height() * 3 / 2)
         # the default is too small. Use at least 2/5 of screen height and 1/4
         # of screen width:
-        available = KApplication.kApplication().desktop().availableGeometry()
+        available = Internal.app.desktop().availableGeometry()
         height = max(result.height(), available.height() * 2 / 5)
         width = max(result.width(), available.width() / 4)
         result.setHeight(height)
@@ -513,9 +502,9 @@ class ScoreTable(QWidget):
             expandGroups = [True, False, True, True]
         gameid = str(self.game.seed or self.game.gameid)
         if self.game.finished():
-            title = m18n('Final scores for game <numid>%1</numid>', gameid)
+            title = i18n('Final scores for game <numid>%1</numid>', gameid)
         else:
-            title = m18n('Scores for game <numid>%1</numid>', gameid)
+            title = i18n('Scores for game <numid>%1</numid>', gameid)
         decorateWindow(self, title)
         self.ruleTree.rulesets = list([self.game.ruleset])
         self.scoreModel = ScoreModel(self)
@@ -526,10 +515,7 @@ class ScoreTable(QWidget):
             header = view.header()
             header.setStretchLastSection(False)
             view.setAlternatingRowColors(True)
-        if usingQt5:
-            self.viewRight.header().setSectionResizeMode(QHeaderView.Fixed)
-        else:
-            self.viewRight.header().setResizeMode(QHeaderView.Fixed)
+        self.viewRight.header().setSectionResizeMode(QHeaderView.Fixed)
         for col in range(self.viewLeft.header().count()):
             self.viewLeft.header().setSectionHidden(col, col > 0)
             self.viewRight.header().setSectionHidden(col, col == 0)
@@ -586,7 +572,7 @@ class ExplainView(QListView):
     def __init__(self, scene):
         QListView.__init__(self)
         self.scene = scene
-        decorateWindow(self, m18n('Explain Scores').replace('&', ''))
+        decorateWindow(self, i18nc("@title:window", "Explain Scores").replace('&', ''))
         self.setGeometry(0, 0, 300, 400)
         self.model = QStringListModel()
         self.setModel(self.model)
@@ -602,10 +588,10 @@ class ExplainView(QListView):
         """refresh for new values"""
         lines = []
         if self.game is None:
-            lines.append(m18n('There is no active game'))
+            lines.append(i18n('There is no active game'))
         else:
-            i18nName = m18n(self.game.ruleset.name)
-            lines.append(m18n('%1', i18nName))
+            i18nName = i18n(self.game.ruleset.name)
+            lines.append(i18n('%1', i18nName))
             lines.append('')
             for player in self.game.players:
                 pLines = []
@@ -618,14 +604,14 @@ class ExplainView(QListView):
                             pLines.append('- ' + line)
                 elif player.handTotal:
                     pLines.append(
-                        m18n(
+                        i18n(
                             'Manual score for %1: %2 points',
                             player.localName,
                             player.handTotal))
                 if pLines:
                     pLines.append('')
                 lines.extend(pLines)
-        if 'xxx'.join(lines) != 'xxx'.join(unicode(x) for x in self.model.stringList()):
+        if 'xxx'.join(lines) != 'xxx'.join(str(x) for x in self.model.stringList()): # TODO: ohne?
             # QStringListModel does not optimize identical lists away, so we do
             self.model.setStringList(lines)
 
@@ -641,19 +627,13 @@ class PenaltyBox(QSpinBox):
 
     def validate(self, inputData, pos):
         """check if value is a multiple of parties"""
-        if usingQt5:
-            result, inputData, newPos = QSpinBox.validate(self, inputData, pos)
-        else:
-            result, newPos = QSpinBox.validate(self, inputData, pos)
+        result, inputData, newPos = QSpinBox.validate(self, inputData, pos)
         if result == QValidator.Acceptable:
             if int(inputData) % self.parties != 0:
                 result = QValidator.Intermediate
         if result == QValidator.Acceptable:
             self.prevValue = str(inputData)
-        if usingQt5:
-            return (result, inputData, newPos)
-        else:
-            return (result, newPos)
+        return (result, inputData, newPos)
 
     def fixup(self, data):
         """change input to a legal value"""
@@ -675,7 +655,7 @@ class RuleBox(QCheckBox):
     """additional attribute: ruleId"""
 
     def __init__(self, rule):
-        QCheckBox.__init__(self, m18n(rule.name))
+        QCheckBox.__init__(self, i18n(rule.name))
         self.rule = rule
 
     def setApplicable(self, applicable):
@@ -692,21 +672,21 @@ class PenaltyDialog(QDialog):
     def __init__(self, game):
         """selection for this player, tiles are the still available tiles"""
         QDialog.__init__(self, None)
-        decorateWindow(self, m18n("Penalty"))
+        decorateWindow(self, i18n("Penalty"))
         self.game = game
         grid = QGridLayout(self)
-        lblOffense = QLabel(m18n('Offense:'))
+        lblOffense = QLabel(i18n('Offense:'))
         crimes = list(
             [x for x in game.ruleset.penaltyRules if not ('absolute' in x.options and game.winner)])
         self.cbCrime = ListComboBox(crimes)
         lblOffense.setBuddy(self.cbCrime)
         grid.addWidget(lblOffense, 0, 0)
         grid.addWidget(self.cbCrime, 0, 1, 1, 4)
-        lblPenalty = QLabel(m18n('Total Penalty'))
+        lblPenalty = QLabel(i18n('Total Penalty'))
         self.spPenalty = PenaltyBox(2)
         self.spPenalty.setRange(0, 9999)
         lblPenalty.setBuddy(self.spPenalty)
-        self.lblUnits = QLabel(m18n('points'))
+        self.lblUnits = QLabel(i18n('points'))
         grid.addWidget(lblPenalty, 1, 0)
         grid.addWidget(self.spPenalty, 1, 1)
         grid.addWidget(self.lblUnits, 1, 2)
@@ -734,15 +714,10 @@ class PenaltyDialog(QDialog):
         grid.addWidget(buttonBox, 7, 0, 1, 5)
         buttonBox.setStandardButtons(QDialogButtonBox.Cancel)
         buttonBox.rejected.connect(self.reject)
-        if not usingKDE:
-            self.btnExecute = buttonBox.addButton(
-                m18n("&Execute"),
-                QDialogButtonBox.AcceptRole)
-            self.btnExecute.clicked.connect(self.accept)
-        else:
-            self.btnExecute = buttonBox.addButton(
-                m18n("&Execute"), QDialogButtonBox.AcceptRole,
-                self, SLOT("accept()"))
+        self.btnExecute = buttonBox.addButton(
+            i18n("&Execute"),
+            QDialogButtonBox.AcceptRole)
+        self.btnExecute.clicked.connect(self.accept)
         self.crimeChanged()
         StateSaver(self)
 
@@ -794,7 +769,7 @@ class PenaltyDialog(QDialog):
         self.spPenalty.setValue(-offense.score.points)
         self.spPenalty.parties = max(payers, payees)
         self.spPenalty.setSingleStep(10)
-        self.lblUnits.setText(m18n('points'))
+        self.lblUnits.setText(i18n('points'))
         self.playerChanged()
         self.penaltyChanged()
 
@@ -815,12 +790,12 @@ class PenaltyDialog(QDialog):
                 if idx < count:
                     if pList == self.payers:
                         player.lblPayment.setText(
-                            m18nc(
+                            i18nc(
                                 'penalty dialog, appears behind paying player combobox',
                                 'pays %1 points', -amount))
                     else:
                         player.lblPayment.setText(
-                            m18nc(
+                            i18nc(
                                 'penalty dialog, appears behind profiting player combobox',
                                 'gets %1 points', amount))
 
@@ -833,7 +808,7 @@ class ScoringDialog(QWidget):
     def __init__(self, scene):
         QWidget.__init__(self)
         self.scene = scene
-        decorateWindow(self, m18n('Scoring for this Hand'))
+        decorateWindow(self, i18nc("@title:window", "Scoring for this Hand"))
         self.nameLabels = [None] * 4
         self.spValues = [None] * 4
         self.windLabels = [None] * 4
@@ -845,20 +820,20 @@ class ScoringDialog(QWidget):
         grid = QGridLayout(self)
         pGrid = QGridLayout()
         grid.addLayout(pGrid, 0, 0, 2, 1)
-        pGrid.addWidget(QLabel(m18nc('kajongg', "Player")), 0, 0)
-        pGrid.addWidget(QLabel(m18nc('kajongg', "Wind")), 0, 1)
-        pGrid.addWidget(QLabel(m18nc('kajongg', 'Score')), 0, 2)
-        pGrid.addWidget(QLabel(m18n("Winner")), 0, 3)
+        pGrid.addWidget(QLabel(i18nc('kajongg', "Player")), 0, 0)
+        pGrid.addWidget(QLabel(i18nc('kajongg', "Wind")), 0, 1)
+        pGrid.addWidget(QLabel(i18nc('kajongg', 'Score')), 0, 2)
+        pGrid.addWidget(QLabel(i18n("Winner")), 0, 3)
         self.detailTabs = QTabWidget()
         self.detailTabs.setDocumentMode(True)
         pGrid.addWidget(self.detailTabs, 0, 4, 8, 1)
         for idx in range(4):
             self.setupUiForPlayer(pGrid, idx)
-        self.draw = QCheckBox(m18nc('kajongg', 'Draw'))
+        self.draw = QCheckBox(i18nc('kajongg', 'Draw'))
         self.draw.clicked.connect(self.wonChanged)
-        btnPenalties = QPushButton(m18n("&Penalties"))
+        btnPenalties = QPushButton(i18n("&Penalties"))
         btnPenalties.clicked.connect(self.penalty)
-        self.btnSave = QPushButton(m18n('&Save Hand'))
+        self.btnSave = QPushButton(i18n('&Save Hand'))
         self.btnSave.clicked.connect(self.game.nextScoringHand)
         self.btnSave.setEnabled(False)
         self.setupUILastTileMeld(pGrid)
@@ -880,7 +855,7 @@ class ScoringDialog(QWidget):
 
     def setupUILastTileMeld(self, pGrid):
         """setup UI elements for last tile and last meld"""
-        self.lblLastTile = QLabel(m18n('&Last Tile:'))
+        self.lblLastTile = QLabel(i18n('&Last Tile:'))
         self.cbLastTile = QComboBox()
         self.cbLastTile.setMinimumContentsLength(1)
         vpol = QSizePolicy()
@@ -889,7 +864,7 @@ class ScoringDialog(QWidget):
         self.cbLastTile.setSizeAdjustPolicy(
             QComboBox.AdjustToMinimumContentsLengthWithIcon)
         self.lblLastTile.setBuddy(self.cbLastTile)
-        self.lblLastMeld = QLabel(m18n('L&ast Meld:'))
+        self.lblLastMeld = QLabel(i18n('L&ast Meld:'))
         self.prevLastTile = None
         self.cbLastMeld = QComboBox()
         self.cbLastMeld.setMinimumContentsLength(1)
@@ -940,8 +915,7 @@ class ScoringDialog(QWidget):
                 if game:
                     self.spValues[idx].setRange(0, game.ruleset.limit or 99999)
                     self.nameLabels[idx].setText(player.localName)
-                    self.windLabels[idx].wind = player.wind
-                    self.windLabels[idx].roundsFinished = game.roundsFinished
+                    self.refreshWindLabels()
                     self.detailTabs.setTabText(idx, player.localName)
                     player.manualRuleBoxes = [RuleBox(x)
                                               for x in game.ruleset.allRules if x.hasSelectable]
@@ -984,7 +958,7 @@ class ScoringDialog(QWidget):
         """returns the currently selected last tile"""
         idx = self.cbLastTile.currentIndex()
         if idx >= 0:
-            return variantValue(self.cbLastTile.itemData(idx))
+            return self.cbLastTile.itemData(idx)
 
     def clickedPlayerIdx(self, checkbox):
         """the player whose box has been clicked"""
@@ -1051,13 +1025,17 @@ class ScoringDialog(QWidget):
         if self.game is None:
             self.hide()
         else:
-            for idx, player in enumerate(self.game.players):
-                self.windLabels[idx].setPixmap(WINDPIXMAPS[(player.wind,
-                                                            player.wind == self.game.roundWind)])
+            self.refreshWindLabels()
             self.computeScores()
             self.spValues[0].setFocus()
             self.spValues[0].selectAll()
 
+    def refreshWindLabels(self):
+        """update their wind and prevailing"""
+        for idx, player in enumerate(self.game.players):
+            self.windLabels[idx].wind = player.wind
+            self.windLabels[idx].roundsFinished = self.game.roundsFinished
+
     def computeScores(self):
         """if tiles have been selected, compute their value"""
         # pylint: disable=too-many-branches
@@ -1121,7 +1099,7 @@ class ScoringDialog(QWidget):
         idx = self.cbLastTile.currentIndex()
         if idx < 0:
             idx = 0
-        indexedTile = variantValue(self.cbLastTile.itemData(idx))
+        indexedTile = self.cbLastTile.itemData(idx)
         restoredIdx = None
         self.cbLastTile.clear()
         if not winnerTiles:
@@ -1137,14 +1115,14 @@ class ScoringDialog(QWidget):
                 shownTiles.add(tile.tile)
                 self.cbLastTile.addItem(
                     QIcon(tile.pixmapFromSvg(pmSize, withBorders=False)),
-                    '', toQVariant(tile.tile))
+                    '', tile.tile)
                 if indexedTile is tile.tile:
                     restoredIdx = self.cbLastTile.count() - 1
         if not restoredIdx and indexedTile:
             # try again, maybe the tile changed between concealed and exposed
             indexedTile = indexedTile.exposed
             for idx in range(self.cbLastTile.count()):
-                if indexedTile is variantValue(self.cbLastTile.itemData(idx)).exposed:
+                if indexedTile is self.cbLastTile.itemData(idx).exposed:
                     restoredIdx = idx
                     break
         if not restoredIdx:
@@ -1187,22 +1165,21 @@ class ScoringDialog(QWidget):
                                    winner.handBoard.tilesByElement(element)
                                    [0].pixmapFromSvg(QSize(faceWidth, faceHeight), withBorders=False))
                 painter.translate(QPointF(faceWidth, 0.0))
-            self.cbLastMeld.addItem(QIcon(pixMap), '', toQVariant(str(meld)))
+            self.cbLastMeld.addItem(QIcon(pixMap), '', str(meld))
             if indexedMeld == str(meld):
                 restoredIdx = self.cbLastMeld.count() - 1
         if not restoredIdx and indexedMeld:
             # try again, maybe the meld changed between concealed and exposed
             indexedMeld = indexedMeld.lower()
             for idx in range(self.cbLastMeld.count()):
-                meldContent = str(variantValue(self.cbLastMeld.itemData(idx)))
+                meldContent = str(self.cbLastMeld.itemData(idx))
                 if indexedMeld == meldContent.lower():
                     restoredIdx = idx
                     if lastTile not in meldContent:
                         lastTile = lastTile.swapped
                         assert lastTile in meldContent
                         with BlockSignals(self.cbLastTile):  # we want to continue right here
-                            idx = self.cbLastTile.findData(
-                                toQVariant(lastTile))
+                            idx = self.cbLastTile.findData(lastTile)
                             self.cbLastTile.setCurrentIndex(idx)
                     break
         if not restoredIdx:
@@ -1219,7 +1196,7 @@ class ScoringDialog(QWidget):
             idx = self.cbLastMeld.currentIndex()
             if idx < 0:
                 idx = 0
-            indexedMeld = str(variantValue(self.cbLastMeld.itemData(idx)))
+            indexedMeld = str(self.cbLastMeld.itemData(idx))
             self.cbLastMeld.clear()
             self.__meldPixMaps = []
             if not self.game.winner:
@@ -1232,10 +1209,7 @@ class ScoringDialog(QWidget):
             assert len(winnerMelds), 'lastTile %s missing in %s' % (
                 lastTile, self.game.winner.hand.melds)
             if len(winnerMelds) == 1:
-                self.cbLastMeld.addItem(
-                    QIcon(),
-                    '',
-                    toQVariant(str(winnerMelds[0])))
+                self.cbLastMeld.addItem(QIcon(), '', str(winnerMelds[0]))
                 self.cbLastMeld.setCurrentIndex(0)
                 return
             showCombo = True
@@ -1252,7 +1226,7 @@ class ScoringDialog(QWidget):
         self.computeScores()
         self.validate()
         for player in self.game.players:
-            self.game.wall.decoratePlayer(player)
+            player.showInfo()
         Internal.mainWindow.updateGUI()
 
     def validate(self):
