@@ -31,8 +31,11 @@ Usage: see ../README.windows
 # ==== adapt this part =====
 FULLAUTHOR = "Wolfgang Rohdewald <wolfgang@rohdewald.de>"
 LICENSE = 'GNU General Public License v2'
-URL = "https://www.kde.org/applications/games/kajongg/"
-VERSION = "17.04"
+URL = "https://kde.org/applications/games/org.kde.kajongg"
+try:
+    from appversion import VERSION
+except ImportError:
+    VERSION = "Unknown"
 # ==========================
 
 import os
